@@ -487,7 +487,7 @@ mod pass_impl {
             indirect_buffer: &super::Buffer,
             indirect_offset: wgt::BufferAddress,
         ) {
-            wgpu_render_pass_bundle_indexed_indirect(self, indirect_buffer.id, indirect_offset)
+            wgpu_render_bundle_draw_indexed_indirect(self, indirect_buffer.id, indirect_offset)
         }
         fn multi_draw_indirect(
             &mut self,
@@ -1352,7 +1352,7 @@ impl crate::Context for Context {
         match wgc::gfx_select!(buffer.id => global.buffer_get_mapped_range(
             buffer.id,
             sub_range.start,
-            wgt::BufferSize::new(size)
+            Some(size)
         )) {
             Ok((ptr, size)) => BufferMappedRange {
                 ptr,
@@ -1412,11 +1412,13 @@ impl crate::Context for Context {
             label: desc.label.map(Borrowed),
             format: desc.format,
             dimension: desc.dimension,
-            aspect: desc.aspect,
-            base_mip_level: desc.base_mip_level,
-            mip_level_count: desc.mip_level_count,
-            base_array_layer: desc.base_array_layer,
-            array_layer_count: desc.array_layer_count,
+            range: wgt::ImageSubresourceRange {
+                aspect: desc.aspect,
+                base_mip_level: desc.base_mip_level,
+                mip_level_count: desc.mip_level_count,
+                base_array_layer: desc.base_array_layer,
+                array_layer_count: desc.array_layer_count,
+            },
         };
         let global = &self.0;
         let (id, error) = wgc::gfx_select!(
@@ -1781,6 +1783,39 @@ impl crate::Context for Context {
         id
     }
 
+    fn command_encoder_clear_image(
+        &self,
+        encoder: &Self::CommandEncoderId,
+        texture: &crate::Texture,
+        subresource_range: &wgt::ImageSubresourceRange,
+    ) {
+        let global = &self.0;
+        if let Err(cause) = wgc::gfx_select!(encoder.id => global.command_encoder_clear_image(
+            encoder.id,
+            texture.id.id,
+            subresource_range
+        )) {
+            self.handle_error_nolabel(&encoder.error_sink, cause, "CommandEncoder::clear_image");
+        }
+    }
+
+    fn command_encoder_clear_buffer(
+        &self,
+        encoder: &Self::CommandEncoderId,
+        buffer: &crate::Buffer,
+        offset: wgt::BufferAddress,
+        size: Option<wgt::BufferSize>,
+    ) {
+        let global = &self.0;
+        if let Err(cause) = wgc::gfx_select!(encoder.id => global.command_encoder_clear_buffer(
+            encoder.id,
+            buffer.id.id,
+            offset, size
+        )) {
+            self.handle_error_nolabel(&encoder.error_sink, cause, "CommandEncoder::clear_buffer");
+        }
+    }
+
     fn command_encoder_insert_debug_marker(&self, encoder: &Self::CommandEncoderId, label: &str) {
         let global = &self.0;
         if let Err(cause) = wgc::gfx_select!(encoder.id => global.command_encoder_insert_debug_marker(encoder.id, &label))
@@ -1897,26 +1932,14 @@ impl crate::Context for Context {
         }
     }
 
-    fn start_capture(&self, device: &Self::DeviceId) {
+    fn device_start_capture(&self, device: &Self::DeviceId) {
         let global = &self.0;
-        let res = wgc::gfx_select!(device.id => global.start_capture(device.id));
-        match res {
-            Ok(v) => v,
-            Err(cause) => {
-                self.handle_error_fatal(cause, "Device::start_capture");
-            }
-        }
+        wgc::gfx_select!(device.id => global.device_start_capture(device.id));
     }
 
-    fn stop_capture(&self, device: &Self::DeviceId) {
+    fn device_stop_capture(&self, device: &Self::DeviceId) {
         let global = &self.0;
-        let res = wgc::gfx_select!(device.id => global.stop_capture(device.id));
-        match res {
-            Ok(v) => v,
-            Err(cause) => {
-                self.handle_error_fatal(cause, "Device::stop_capture");
-            }
-        }
+        wgc::gfx_select!(device.id => global.device_stop_capture(device.id));
     }
 }
 
@@ -1950,7 +1973,7 @@ impl fmt::Debug for ErrorSinkRaw {
 }
 
 fn default_error_handler(err: crate::Error) {
-    eprintln!("wgpu error: {}\n", err);
+    log::error!("wgpu error: {}\n", err);
 
     panic!("Handling wgpu errors as fatal by default");
 }
