@@ -1,5 +1,4 @@
 use std::{
-    collections::HashSet,
     fmt,
     future::Future,
     ops::Range,
@@ -1081,7 +1080,7 @@ impl crate::Context for Context {
         }
     }
 
-    fn adapter_downlevel_properties(&self, adapter: &Self::AdapterId) -> wgt::DownlevelProperties {
+    fn adapter_downlevel_properties(&self, _adapter: &Self::AdapterId) -> wgt::DownlevelProperties {
         // WebGPU is assumed to be fully compliant
         wgt::DownlevelProperties::default()
     }
@@ -1149,9 +1148,12 @@ impl crate::Context for Context {
                     flags: spv::WriterFlags::empty(),
                     capabilities: None,
                 };
-                let analysis = Validator::new(naga::valid::ValidationFlags::all())
-                    .validate(&module)
-                    .unwrap();
+                let analysis = Validator::new(
+                    naga::valid::ValidationFlags::empty(),
+                    naga::valid::Capabilities::all(),
+                )
+                .validate(&module)
+                .unwrap();
                 let words = spv::write_vec(&module, &analysis, &options).unwrap();
                 web_sys::GpuShaderModuleDescriptor::new(&js_sys::Uint32Array::from(&words[..]))
             }
@@ -1897,6 +1899,23 @@ impl crate::Context for Context {
         })
     }
 
+    fn command_encoder_clear_image(
+        &self,
+        _encoder: &Self::CommandEncoderId,
+        _texture: &crate::Texture,
+        _subresource_range: &wgt::ImageSubresourceRange,
+    ) {
+    }
+
+    fn command_encoder_clear_buffer(
+        &self,
+        _encoder: &Self::CommandEncoderId,
+        _buffer: &crate::Buffer,
+        _offset: wgt::BufferAddress,
+        _size: Option<wgt::BufferSize>,
+    ) {
+    }
+
     fn command_encoder_insert_debug_marker(&self, _encoder: &Self::CommandEncoderId, _label: &str) {
         // Not available in gecko yet
         // encoder.insert_debug_marker(label);
@@ -1918,7 +1937,7 @@ impl crate::Context for Context {
         _query_set: &Self::QuerySetId,
         _query_index: u32,
     ) {
-        // Not available in gecko yet
+        unimplemented!();
     }
 
     fn command_encoder_resolve_query_set(
@@ -1930,7 +1949,7 @@ impl crate::Context for Context {
         _destination: &Self::BufferId,
         _destination_offset: wgt::BufferAddress,
     ) {
-        // Not available in gecko yet
+        unimplemented!();
     }
 
     fn render_bundle_encoder_finish(
@@ -2024,9 +2043,8 @@ impl crate::Context for Context {
         1.0 //TODO
     }
 
-    fn start_capture(&self, device: &Self::DeviceId) {}
-
-    fn stop_capture(&self, device: &Self::DeviceId) {}
+    fn device_start_capture(&self, _device: &Self::DeviceId) {}
+    fn device_stop_capture(&self, _device: &Self::DeviceId) {}
 }
 
 pub(crate) type SwapChainOutputDetail = ();
